System and Service Status Monitoring and Reporting
==================================================

The package is used for monitoring and reporting system and
service information and putting it at custom etcd paths.